@@ -79,9 +79,9 @@ def parse_input(command_input=None):
     testing = parser.add_argument_group('running tests')
     testing.add_argument('-q', '--question', type=str, action='append',
                         help="run tests for a specific question")
-    testing.add_argument('--suite', type=int, default=None,
+    testing.add_argument('--suite', type=str, default=None,
                         help="run cases from a specific suite")
-    testing.add_argument('--case', type=int, action='append',
+    testing.add_argument('--case', type=str, action='append',
                         help="run specific cases")
     testing.add_argument('-u', '--unlock', action='store_true',
                         help="unlock tests interactively")
@@ -89,6 +89,8 @@ def parse_input(command_input=None):
                         help="start the Python interpreter after a failed test")
     testing.add_argument('-v', '--verbose', action='store_true',
                         help="show all tests, not just passing tests")
+    testing.add_argument('-t', '--testing', nargs='?', type=str, const='mytests.rst', 
+                        help='run tests from rst file (default: mytests.rst)')
     testing.add_argument('--all', action='store_true',
                         help="run tests for all questions in config file")
     testing.add_argument('--submit', action='store_true',
@@ -97,15 +99,15 @@ def parse_input(command_input=None):
                         help="attempt to reliably backup your work")
     testing.add_argument('--revise', action='store_true',
                         help="submit composition revision")
-    testing.add_argument('--restore', action='store_true',
-                        help="restore assignment from an earlier backup")
     testing.add_argument('--timeout', type=int, default=10,
                         help="set the timeout duration (in seconds) for running tests")
+    testing.add_argument('-cov', '--coverage', action='store_true',
+                        help="get suggestions on what lines to add tests for")
 
     # Experiments
     experiment = parser.add_argument_group('experiment options')
-    experiment.add_argument('--no-hints', action='store_true',
-                        help="do not give hints")
+    experiment.add_argument('--no-experiments', action='store_true',
+                        help="do not run experimental features")
     experiment.add_argument('--hint', action='store_true',
                         help="give a hint (if available)")
     experiment.add_argument('--style', action='store_true',
@@ -128,8 +130,9 @@ def parse_input(command_input=None):
                         help="lock the tests in a directory")
     grading.add_argument('--score', action='store_true',
                         help="score the assignment")
-    grading.add_argument('--score-out', type=argparse.FileType('w'),
-                        default=sys.stdout, help="write scores to a file")
+    grading.add_argument('--score-out', type=str,
+                        nargs='?', const=None, default=None,
+                        help="write scores to a file")
     grading.add_argument('--config', type=str,
                         help="use a specific configuration file")
 
@@ -142,6 +145,8 @@ def parse_input(command_input=None):
                         help="set the server address")
     server.add_argument('--authenticate', action='store_true',
                         help="authenticate, ignoring previous authentication")
+    server.add_argument('--no-browser', action='store_true',
+                        help="do not use a web browser for authentication")
     server.add_argument('--get-token', action='store_true',
                         help="get ok access token")
     server.add_argument('--insecure', action='store_true',
@@ -156,13 +161,12 @@ def parse_input(command_input=None):
 def main():
     """Run all relevant aspects of ok.py."""
     args = parse_input()
-
     log.setLevel(logging.DEBUG if args.debug else logging.ERROR)
     log.debug(args)
 
     # Checking user's Python bit version
     bit_v = (8 * struct.calcsize("P"))
-    log.debug("Python {}bit".format(bit_v))
+    log.debug("Python {} ({}bit)".format(sys.version, bit_v))
 
     if args.version:
         print("okpy=={}".format(client.__version__))
@@ -173,21 +177,21 @@ def main():
                 args.server, client.__version__, client.FILE_NAME, timeout=10)
         exit(not did_update)  # exit with error if ok failed to update
 
-    if args.get_token:
-        access_token = auth.authenticate(True)
-        print("Token: {}".format(access_token))
-        exit(not access_token)  # exit with error if no access_token
-
     assign = None
     try:
-        if args.authenticate:
-            # Authenticate and check for success
-            if not auth.authenticate(True):
-                exit(1)
+        if args.get_token:
+            access_token = auth.authenticate(args, force=True)
+            print("Token: {}".format(access_token))
+            exit(not access_token)  # exit with error if no access_token
 
         # Instantiating assignment
         assign = assignment.load_assignment(args.config, args)
 
+        if args.authenticate:
+            # Authenticate and check for success
+            if not assign.authenticate(force=True):
+                exit(1)
+
         if args.tests:
             print('Available tests:')
             for name in assign.test_map:
@@ -207,13 +211,16 @@ def main():
     except ex.AuthenticationException as e:
         log.warning('Authentication exception occurred', exc_info=True)
         print('Authentication error: {0}'.format(e))
+    except ex.EarlyExit as e:
+        log.warning('OK exited early (non-error)')
+        print(str(e))
     except ex.OkException as e:
         log.warning('General OK exception occurred', exc_info=True)
         print('Error: ' + str(e))
     except KeyboardInterrupt:
         log.info('KeyboardInterrupt received.')
     finally:
-        if not args.no_update:
+        if not args.no_update and not args.local:
             try:
                 software_update.check_version(args.server, client.__version__,
                                               client.FILE_NAME)
