@@ -7,7 +7,9 @@ are compatible with the GradingProtocol.
 
 from client.protocols.common import models
 from client.utils import format
+from client.utils import storage
 import logging
+import sys
 
 log = logging.getLogger(__name__)
 
@@ -19,7 +21,7 @@ class GradingProtocol(models.Protocol):
     """A Protocol that runs tests, formats results, and sends results
     to the server.
     """
-    def run(self, messages):
+    def run(self, messages, env=None):
         """Run gradeable tests and print results and return analytics.
 
         RETURNS:
@@ -28,16 +30,20 @@ class GradingProtocol(models.Protocol):
         significant for analytics. However, all tests must include the number
         passed, the number of locked tests and the number of failed tests.
         """
-        if self.args.score or self.args.unlock or self.args.restore:
+        if self.args.score or self.args.unlock or self.args.testing:
             return
         tests = self.assignment.specified_tests
         for test in tests:
             if self.args.suite and hasattr(test, 'suites'):
                 test.run_only = self.args.suite
-                suite = test.suites[self.args.suite - 1]
+                try:
+                    suite = test.suites[self.args.suite - 1]
+                except IndexError as e:
+                    sys.exit(('python3 ok: error: '
+                        'Suite number must be valid.({})'.format(len(test.suites))))
                 if self.args.case:
                     suite.run_only = self.args.case
-        grade(tests, messages, verbose=self.args.verbose)
+        grade(tests, messages, env, verbose=self.args.verbose)
 
 
 def grade(questions, messages, env=None, verbose=True):
@@ -54,6 +60,11 @@ def grade(questions, messages, env=None, verbose=True):
     for test in questions:
         log.info('Running tests for {}'.format(test.name))
         results = test.run(env)
+
+        # if correct once, set persistent flag
+        if results['failed'] == 0 and results['locked'] == 0:
+            storage.store(test.name, 'correct', True)
+
         passed += results['passed']
         failed += results['failed']
         locked += results['locked']
