@@ -31,12 +31,16 @@ class UnlockProtocol(models.Protocol):
         'exit()',
         'quit()',
     )
+    SPECIAL_INPUTS = (  # Inputs that are not from the interpreter
+        'Error',
+        'Infinite Loop',
+        'Nothing',
+    )
 
     def __init__(self, cmd_args, assignment):
         super().__init__(cmd_args, assignment)
         self.hash_key = assignment.name
         self.analytics = []
-        self.access_token = None
         self.guidance_util = guidance.Guidance("", assignment=assignment)
 
     def run(self, messages):
@@ -51,8 +55,6 @@ class UnlockProtocol(models.Protocol):
         """
         if not self.args.unlock:
             return
-        if not self.args.local:
-            self.access_token = auth.authenticate(False)
 
         format.print_line('~')
         print('Unlocking tests')
@@ -67,6 +69,9 @@ class UnlockProtocol(models.Protocol):
             log.info('Unlocking test {}'.format(test.name))
             self.current_test = test.name
 
+            # Reset guidance explanation probability for every question
+            self.guidance_util.prompt_probability = guidance.DEFAULT_PROMPT_PROBABILITY
+
             try:
                 test.unlock(self.interact)
             except (KeyboardInterrupt, EOFError):
@@ -141,30 +146,24 @@ class UnlockProtocol(models.Protocol):
                 if choices and student_input in choice_map:
                     student_input = choice_map[student_input]
 
-                input_lines.append(student_input)
-                if not self._verify(student_input, line):
-                    # Try to evaluate student answer as Python expression and
-                    # use the result as the answer.
-                    try:
-                        eval_input = repr(ast.literal_eval(student_input))
-                        if not self._verify(eval_input, answer[line_number]):
-                            break
-                        # Replace student_input with evaluated input.
-                        input_lines[-1] = eval_input
-                    except Exception as e:
-                        # Incorrect answer.
-                        break
-
+                correct_answer = self._verify_student_input(student_input, line)
+                if correct_answer:
+                    input_lines.append(correct_answer)
+                else:
+                    input_lines.append(student_input)
+                    break
             else:
                 correct = True
             tg_id = -1
             misU_count_dict = {}
+            rationale = "Unknown - Default Value"
 
             if not correct:
-                misU_count_dict, tg_id, printed_msg = self.guidance_util.show_guidance_msg(unique_id,input_lines,
-                    self.access_token, self.hash_key)
-
+                guidance_data = self.guidance_util.show_guidance_msg(unique_id, input_lines,
+                                                                     self.hash_key)
+                misU_count_dict, tg_id, printed_msg, rationale = guidance_data
             else:
+                rationale = self.guidance_util.prompt_with_prob()
                 print("-- OK! --")
                 printed_msg = ["-- OK! --"]
 
@@ -177,6 +176,7 @@ class UnlockProtocol(models.Protocol):
                 'answer': input_lines,
                 'correct': correct,
                 'treatment group id': tg_id,
+                'rationale': rationale,
                 'misU count': misU_count_dict,
                 'printed msg': printed_msg
             })
@@ -187,6 +187,21 @@ class UnlockProtocol(models.Protocol):
     # Private Methods #
     ###################
 
+    def _verify_student_input(self, student_input, locked):
+        """If the student's answer is correct, returns the normalized answer.
+        Otherwise, returns None.
+        """
+        guesses = [student_input]
+        try:
+            guesses.append(repr(ast.literal_eval(student_input)))
+        except Exception:
+            pass
+        if student_input.title() in self.SPECIAL_INPUTS:
+            guesses.append(student_input.title())
+        for guess in guesses:
+            if self._verify(guess, locked):
+                return guess
+
     def _verify(self, guess, locked):
         return locking.lock(self.hash_key, guess) == locked
 
